@@ -1,7 +1,7 @@
 // padthv1_lv2ui.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,7 +22,11 @@
 #include "padthv1_lv2ui.h"
 #include "padthv1_lv2.h"
 
+#ifdef CONFIG_LV2_OLD_HEADERS
 #include "lv2/lv2plug.in/ns/ext/instance-access/instance-access.h"
+#else
+#include "lv2/instance-access/instance-access.h"
+#endif
 
 #include <padthv1widget_lv2.h>
 
