@@ -1,7 +1,7 @@
 // padthv1_param.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -256,7 +256,7 @@ bool padthv1_param::loadPreset (
 	const QDir currentDir(QDir::current());
 	QDir::setCurrent(fi.absolutePath());
 
-	QDomDocument doc(PADTHV1_TITLE);
+	QDomDocument doc(PROJECT_NAME);
 	if (doc.setContent(&file)) {
 		QDomElement ePreset = doc.documentElement();
 		if (ePreset.tagName() == "preset") {
@@ -326,10 +326,10 @@ bool padthv1_param::savePreset (
 	const QDir currentDir(QDir::current());
 	QDir::setCurrent(fi.absolutePath());
 
-	QDomDocument doc(PADTHV1_TITLE);
+	QDomDocument doc(PROJECT_NAME);
 	QDomElement ePreset = doc.createElement("preset");
 	ePreset.setAttribute("name", fi.completeBaseName());
-	ePreset.setAttribute("version", CONFIG_BUILD_VERSION);
+	ePreset.setAttribute("version", PROJECT_VERSION);
 
 	QDomElement eSamples = doc.createElement("samples");
 	padthv1_param::saveSamples(pSynth, doc, eSamples, bSymLink);
